# xh-bin

https://github.com/ducaale/xh

`xh` is a friendly and fast tool for sending HTTP requests. It reimplements as much as possible of [HTTPie's](https://httpie.io/) excellent design, with a focus on improved performance.

[![asciicast](https://github.com/ducaale/xh/raw/master/assets/xh-demo.gif)](https://asciinema.org/a/475190)

## install

```sh
pip install xh-bin
```
